<?php
// BirdsEye 3 Component
//
// Ajax Requests file - allows polling for new data, creates json, returns to the component
// so it can display it out every 1-5 mins depending on users settings
//
// Copyright (c) 2013 Nagios Enterprises, LLC.  All rights reserved.
// 

require_once(dirname(__FILE__).'/../../common.inc.php');
//require_once(dirname(__FILE__).'/includes/xml2json.php');

// initialization stuff
pre_init();

// start session
init_session();

// grab GET or POST variables 
grab_request_vars();

// check prereqs
check_prereqs();

// check authentication
check_authentication(false);

// Route the request sent to this php file
function route_request() {
    
    $mode = grab_request_var('mode');
    
    switch($mode) {
        case 'get_all_down':
            get_all_down();
            break;
        default:
            break;
    }
}

route_request();

// =====================================================
// Handle Ajax Requests
// =====================================================




// =====================================================
// Functions
// =====================================================

function get_all_down()
{
    // AJAX STUFF THAT WE SHOULD BE DOING BEHIND THE SCENES!
    $down = array();

    // Get down host status
    $hosts_xml = get_xml_host_status(array());

    //echo "<pre>";
    //print_r($hosts_xml);
    //echo "</pre>";

    foreach ($hosts_xml->hoststatus as $host) {
        $cs = intval($host->current_state);
        if ($cs > 0) {
            if ($cs == 1) { $type = "critical"; }
            else if ($cs == 2) { $type = "warning"; }
            else { $type = "online"; }
            $host_id = intval($host->host_id);
            $down[$host_id] = array("name" => strval($host->name),
                    "type" => $type,
                    "host_id" => $host_id,
                    "icon" => strval($host->icon_image),
                    "down_services" => array());
        }
    }

    // Get down service status
    $services_xml = get_xml_service_status(array());
    foreach ($services_xml->servicestatus as $service) {
        $cs = intval($service->current_state);
        if ($cs > 0) {
            $host_id = intval($service->host_id);
            if (!array_key_exists($host_id, $down)) {
                // Host is up but a service is down
                $xml = get_xml_host_objects(array("host_id" => $host_id));
                $down[$host_id] = array("name" => strval($xml->host->host_name),
                        "type" => "online",
                        "host_id" => $host_id,
                        "icon" => strval($xml->host->icon_image),
                        "down_services" => array());
            }

            // Add down service to array
            if ($down[$host_id]['type'] != "critical") {
                $down[$host_id]['down_services'][] = array("service_name" => strval($service->name));
            }
        }
    }

    // Loop through and create a new array (making the critical hosts be on top)
    $to_json = array();
    foreach ($down as $host) {
        $to_json[] = $host;
    }

    //print_r($down);

    print json_encode($to_json);
}
