<?php
// MongoDB Database CONFIG WIZARD
//
// Copyright (c) 2013 Nagios Enterprises, LLC.  All rights reserved.
//  
// $Id: $

include_once(dirname(__FILE__).'/../configwizardhelper.inc.php');

function is_valid_domain_name($domain_name)
{
    return (preg_match("/^([a-z\d](-*[a-z\d])*)(\.([a-z\d](-*[a-z\d])*))*$/i", $domain_name) //valid chars check
            && preg_match("/^.{1,253}$/", $domain_name) //overall length check
            && preg_match("/^[^\.]{1,63}(\.[^\.]{1,63})*$/", $domain_name)   ); //length of each label
}

// run the initialization function
domain_expiration_configwizard_init();

function domain_expiration_configwizard_init()
{
    $name="domain_expiration";
    
    $args=array(
        CONFIGWIZARD_NAME => $name,
        CONFIGWIZARD_VERSION => "1.0",
        CONFIGWIZARD_TYPE => CONFIGWIZARD_TYPE_MONITORING,
        CONFIGWIZARD_DESCRIPTION => gettext("Monitor a domain expiration"),
        CONFIGWIZARD_DISPLAYTITLE => gettext("Domain Expiration"),
        CONFIGWIZARD_FUNCTION => "domain_expiration_configwizard_func",
        CONFIGWIZARD_PREVIEWIMAGE => "domain_expiration.png",
        );
        
    register_configwizard($name,$args);
}

function domain_expiration_configwizard_check_prereqs()
{
    $errors = array();

    if(!file_exists("/usr/local/nagios/libexec/check_domain.sh")){
        $errors[] = gettext('It looks like you are missing Domain Expiration on your Nagios XI server. To use this wizard you must install domain expiration on your server.');
    }

    exec( "which whois 2>&1" , $output, $return_var);

    if( $return_var != 0){
        $errors[] = gettext('It looks like you are missing jWhois on your Nagios XI server. Run: <p><b>yum install jwhois -y</b></p> as root user on your Nagios XI server.');
    }
    
    return $errors;
}

function domain_expiration_configwizard_func($mode="",$inargs=null,&$outargs,&$result)
{
    $wizard_name="domain_expiration";
    
    // initialize return code and output
    $result=0;
    $output="";
    
    // initialize output args - pass back the same data we got
    $outargs[CONFIGWIZARD_PASSBACK_DATA]=$inargs;

    switch($mode){
        case CONFIGWIZARD_MODE_GETSTAGE1HTML:

            $errors = domain_expiration_configwizard_check_prereqs();

            if($errors) {
                $output.='<div class="message"><ul class="errorMessage">';
                foreach($errors as $error) {
                    $output.="<li><p>$error</p></li>";
                }
                $output.='</ul></div>';
            }
            else {
        
                $address=grab_array_var($inargs,"address","");
                
                // Save data from clicking "back" in stage 2
                $services=grab_array_var($inargs,"services",array());
                $serviceargs=grab_array_var($inargs,"serviceargs",array());
                
                $output='

        <input type="hidden" name="services_serial" value="'.base64_encode(serialize($services)).'" />
        <input type="hidden" name="serviceargs_serial" value="'.base64_encode(serialize($serviceargs)).'" />
                
    <div class="sectionTitle">'.gettext('Domain Expiration Information').'</div>
    
    <p>
    '.gettext('Specify the details for connecting to the Domain you want to monitor').'.
    </p>
            
    <table>

    <tr>
    <td valign="top">
    <label>'.gettext('Address').':</label><br class="nobr" />
    </td>
    <td>
<input type="text" size="40" name="address" id="address" value="'.htmlentities($address).'" class="textfield" /><br class="nobr" />
    '.gettext('Add the domain that will be monitored here').'.<br><br>
    </td>
    </tr>   
    
    </table>

            ';
            }
            break;
            
        case CONFIGWIZARD_MODE_VALIDATESTAGE1DATA:
        
            // get variables that were passed to us
            $address=grab_array_var($inargs,"address","");
            
            // check for errors
            $errors=0;
            $errmsg=array();
            if(have_value($address)==false)
                $errmsg[$errors++]="No address specified.";

            if($errors>0){
                $outargs[CONFIGWIZARD_ERROR_MESSAGES]=$errmsg;
                $result=1;
            }
                
            break;
            
        case CONFIGWIZARD_MODE_GETSTAGE2HTML:
        
            // get variables that were passed to us
            $address=grab_array_var($inargs,"address");
            $warning=grab_array_var($inargs,"warning");
            $critical=grab_array_var($inargs,"critical");

            /*
            $ha=@gethostbyaddr($address);
            if($ha=="")
                $ha=$address;
            $address=grab_array_var($inargs,"address",$ha);
            */

            $output='

            
        <input type="hidden" name="address" value="'.htmlentities($address).'" />
    
    <div class="sectionTitle">'.gettext('Domain Expiration').'</div>
            
    <table>
    
    <tr>
    <td valign="top">
    <label>'.gettext('Address').':</label><br class="nobr" />
    </td>
    <td>
<input type="text" size="20" name="address" id="address" value="'.htmlentities($address).'" class="textfield" disabled/><br class="nobr" />
    </td>
    </tr>

    <tr>
    <td valign="top">
    <label>'.gettext('Warning').':</label><br class="nobr" />
    </td>
    <td>
<input type="text" size="5" name="warning" id="warning" value="'.htmlentities($warning).'" class="textfield" /> '.gettext('days').'<br class="nobr" />
    </td>
    </tr>

    <tr>
    <td valign="top">
    <label>'.gettext('Critical').':</label><br class="nobr" />
    </td>
    <td>
<input type="text" size="5" name="critical" id="critical" value="'.htmlentities($critical).'" class="textfield" /> '.gettext('days').'<br class="nobr" />
    </td>
    </tr>

    </table>
    ';
            break;
            
        case CONFIGWIZARD_MODE_VALIDATESTAGE2DATA:
        
            // get variables that were passed to us
            $address=grab_array_var($inargs,"address");
            $warning=grab_array_var($inargs,"warning");
            $critical=grab_array_var($inargs,"critical");
            
            // check for errors
            $errors=0;
            $errmsg=array();
            if(is_valid_domain_name($address)==false)
                $errmsg[$errors++]="Invalid address name.";
                
            if($errors>0){
                $outargs[CONFIGWIZARD_ERROR_MESSAGES]=$errmsg;
                $result=1;
                }
                
            break;

        case CONFIGWIZARD_MODE_GETSTAGE3OPTS: 

            $output.=gettext('The selected domain will be checked once per day.  Click Finish to continue.');
            $result=CONFIGWIZARD_HIDE_OPTIONS;

            break;
            
        case CONFIGWIZARD_MODE_GETSTAGE3HTML:
            
            // get variables that were passed to us
            $address=grab_array_var($inargs,"address");
            $warning=grab_array_var($inargs,"warning");
            $critical=grab_array_var($inargs,"critical");

            $output='
            
                <input type="hidden" name="address" value="'.htmlentities($address).'" />
                <input type="hidden" name="warning" value="'.htmlentities($warning).'" />
                <input type="hidden" name="critical" value="'.htmlentities($critical).'" />
        
            ';
            break;
            
        case CONFIGWIZARD_MODE_VALIDATESTAGE3DATA:

            $address=grab_array_var($inargs,"address");
            $warning=grab_array_var($inargs,"warning");
            $critical=grab_array_var($inargs,"critical");
             
            break;
            
        case CONFIGWIZARD_MODE_GETFINALSTAGEHTML:
            
            $address=grab_array_var($inargs,"address");
            $warning=grab_array_var($inargs,"warning");
            $critical=grab_array_var($inargs,"critical");

            $output='

                <input type="hidden" name="address" value="'.htmlentities($address).'" />
                <input type="hidden" name="warning" value="'.htmlentities($warning).'" />
                <input type="hidden" name="critical" value="'.htmlentities($critical).'" />

            ';
            break;
            
        case CONFIGWIZARD_MODE_GETOBJECTS:
        
            $address=grab_array_var($inargs,"address","");
            $warning=grab_array_var($inargs,"warning");
            $critical=grab_array_var($inargs,"critical");

            // save data for later use in re-entrance
            $meta_arr=array();
            $meta_arr["address"]=$address;
            $meta_arr["warning"]=$warning;
            $meta_arr["critical"]=$critical;
            save_configwizard_object_meta($wizard_name,$address,"",$meta_arr);
            
            $objs=array();
            
            if(!host_exists($address)){
                $objs[]=array(
                    "type" => OBJECTTYPE_HOST,
                    "use" => "xiwizard_domain_expiration_host",
                    "host_name" => $address,
                    "address" => $address,
                    "icon_image" => "domain_expiration.png",
                    "statusmap_image" => "domain_expiration.png",
                    "_xiwizard" => $wizard_name,
                    );

               $objs[]=array(
                            "type" => OBJECTTYPE_SERVICE,
                            "host_name" => $address,
                            "service_description" => "Domain Expiration",
                            "use" => "xiwizard_domain_expiration_service",
                            "check_command" => "check_xi_domain!".$address."!-w ".$warning."!-c ".$critical,
                            "check_interval" => 1440,
                            "_xiwizard" => $wizard_name,
                            );
            }

            
            // return the object definitions to the wizard
            $outargs[CONFIGWIZARD_NAGIOS_OBJECTS]=$objs;

            break;

        default:
            break;          
        }

    return $output;
}
?>
