<?php
// SNMP TRAP SENDER COMPONENT
//
// Copyright (c) 2010 Nagios Enterprises, LLC.  All rights reserved.
//  
// $Id: snmptrapsender.inc.php 532 2012-03-02 15:40:15Z egalstad $

require_once(dirname(__FILE__).'/../componenthelper.inc.php');

// respect the name
$nagiosna_component_name="nagiosna";

// Use the config constant
if(!defined('NAGIOSNA_CONFIG')) {
    define('NAGIOSNA_CONFIG', get_root_dir().'/var/components/nagiosna/config.inc.php');
}

if(!function_exists('create_config_if_necessary')) {
    function create_config_if_necessary() {
        $dirname = dirname(NAGIOSNA_CONFIG);
        
        if(!file_exists($dirname)) {
            echo "Directory did not exist";
            mkdir($dirname, 0775, true);
        }
        
        if(!file_exists(NAGIOSNA_CONFIG)) {
            echo "Config did not exist";
            file_put_contents(NAGIOSNA_CONFIG, '');
        }
    }
}

// run the initialization function
nagiosna_component_init();

// Create the config
create_config_if_necessary();

////////////////////////////////////////////////////////////////////////
// COMPONENT INIT FUNCTIONS
////////////////////////////////////////////////////////////////////////

function nagiosna_component_init(){
    global $nagiosna_component_name;
    
    $desc="";

    // check XI version
    $versionok=nagiosna_component_checkversion();
    if(!$versionok)
        $desc.="<b>Error: This component requires Nagios XI 2011R3.2 or later.</b>  ";
    
    $args=array(

        // need a name
        COMPONENT_NAME => $nagiosna_component_name,
        
        // informative information
        COMPONENT_AUTHOR => "Nagios Enterprises, LLC",
        COMPONENT_DESCRIPTION => "Allows Nagios Network Analyzer to dynamically add hosts and services.  ".$desc,
        COMPONENT_TITLE => "Nagios Network Analyzer Component",
        COMPONENT_VERSION => "1.0",
        COMPONENT_DATE => '11/5/2013',

        // configuration function (optional)
        COMPONENT_CONFIGFUNCTION => "nagiosna_component_config_func",
        );
        
    register_component($nagiosna_component_name,$args);
    
    }
    

///////////////////////////////////////////////////////////////////////////////////////////
//CONFIG FUNCTIONS
///////////////////////////////////////////////////////////////////////////////////////////

function nagiosna_component_config_func($mode="",$inargs,&$outargs,&$result){
    global $nagiosna_component_name;

    // initialize return code and output
    $result=0;
    $output="";
    

    switch($mode){
        case COMPONENT_CONFIGMODE_GETSETTINGSHTML:

            // defaults
            $nagiosna_instances=array();
            for($x=0;$x<=4;$x++){
                $nagiosna_instances[$x]=array(
                    "address" => "",
                    );
                }
            $settings_raw=file_get_contents(NAGIOSNA_CONFIG);
            //~ $settings_raw=get_option("nagiosna_component_options");
            if($settings_raw==""){
                $settings=array(
                    "enabled"=>0,
                    );
                }
            else
                $settings=unserialize($settings_raw);
                
            //print_r($settings);
                
            // initial values
            $enabled=grab_array_var($settings,"enabled","");
            $nagiosna_instances=grab_array_var($settings,"nagiosna_instances",$nagiosna_instances);
            
            // values passed to us
            $enabled=checkbox_binary(grab_array_var($inargs,"enabled",$enabled));
            $nagiosna_instances=grab_array_var($inargs,"nagiosna_instances",$nagiosna_instances);
            
            $component_url=get_component_url_base($nagiosna_component_name);
            
            $output='';


            $output.='
            
                    
    <div class="sectionTitle">Integration Settings</div>
    
    <table>

    <tr>
    <td valign="top">
    <label for="enabled">Enable Integration:</label><br class="nobr" />
    </td>
    <td>
    <input type="checkbox" class="checkbox" id="enabled" name="enabled" '.is_checked($enabled,1).'>
<br class="nobr" />
    Enables Nagios Network Analyzer dynamic functionality.
    </td>
    </tr>

    </table>

    <div class="sectionTitle">Allowed Nagios Network Analyzer Hosts</div>
    
    <p>
    Specify the addresses of the hosts that service and host directives should be received from.
    </p>
    
    <table class="standardtable">
    <tr><th>Allowed Host</th></tr>
    ';
    
    for($x=0;$x<=2;$x++){

        $output.='
    <tr>
    <td>
<input type="text" size="25" name="nagiosna_instances['.$x.'][address]" value="'.htmlentities($nagiosna_instances[$x]["address"]).'" class="textfield" />
    </td>
    </tr>
        ';
        }
        
    $output.='
    </table>';

            break;
            
        case COMPONENT_CONFIGMODE_SAVESETTINGS:
        
            // get variables
            $enabled=checkbox_binary(grab_array_var($inargs,"enabled",""));
            $nagiosna_instances=grab_array_var($inargs,"nagiosna_instances","");
            
            // validate variables
            $errors=0;
            $errmsg=array();
            if($enabled==1){
                }
            
            // handle errors
            if($errors>0){
                $outargs[COMPONENT_ERROR_MESSAGES]=$errmsg;
                $result=1;
                return '';
                }
            
            // save settings
            $settings=array(
                "enabled" => $enabled,
                "nagiosna_instances" => $nagiosna_instances,
                );
            file_put_contents(NAGIOSNA_CONFIG,serialize($settings));
            //~ set_option("nagiosna_component_options",serialize($settings));
            
        
            // info messages
            $okmsg=array();
            $okmsg[]="Settings updated.";
            $outargs[COMPONENT_INFO_MESSAGES]=$okmsg;
            
            break;
        
        default:
            break;
            
        }
        
    return $output;
    }

///////////////////////////////////////////////////////////////////////////////////////////
// MISC FUNCTIONS
///////////////////////////////////////////////////////////////////////////////////////////

function nagiosna_component_checkversion(){

    if(!function_exists('get_product_release'))
        return false;
    //requires greater than 20011R3.2
    if(get_product_release()<208)
        return false;

    return true;
    }

?>
